==> ace_6.2.7%2Bdfsg.orig.tar.gz: ace-6.2.7+dfsg.orig/MPC/modules/VC14ProjectCreator.pm <==
package VC14ProjectCreator;

# ************************************************************
# Description   : A VC12 Project Creator
# Author        : Johnny Willemsen
# Create Date   : 10/29/2013
# $Id: VC14ProjectCreator.pm 2207 2014-06-04 09:35:35Z johnnyw $
# ************************************************************

# ************************************************************
# Pragmas
# ************************************************************

use strict;

use VC10ProjectCreator;

use vars qw(@ISA);
@ISA = qw(VC10ProjectCreator);

## NOTE: We call the constant as a function to support Perl 5.6.
my %info = (Creator::cplusplus() => {'ext'      => '.vcxproj',
                                     'dllexe'   => 'vc14exe',
                                     'libexe'   => 'vc14libexe',
                                     'dll'      => 'vc14dll',
                                     'lib'      => 'vc14lib',
                                     'template' => [ 'vc10', 'vc10filters' ],
                                    },
           );

my %config = ('vcversion' => '14.00',
              'prversion' => '10.0.30319.1',
              'toolsversion' => '4.0',
              'targetframeworkversion' => '4.0',
              'xmlheader' => 1
              );

# ************************************************************
# Subroutine Section
# ************************************************************

sub get_info_hash {
  my($self, $key) = @_;

  ## If we have the setting in our information map, the use it.
  return $info{$key} if (defined $info{$key});

  ## Otherwise, see if our parent type can take care of it.
  return $self->SUPER::get_info_hash($key);
}

sub get_configurable {
  my($self, $name) = @_;
  return $config{$name};
}

1;

==> ace_6.2.8%2Bdfsg.orig.tar.gz: ace-6.2.8+dfsg.orig/MPC/modules/VC14ProjectCreator.pm <==
package VC14ProjectCreator;

# ************************************************************
# Description   : A VC14 Project Creator
# Author        : Johnny Willemsen
# Create Date   : 6/04/2014
# $Id: VC14ProjectCreator.pm 2215 2014-06-30 17:37:41Z elliott_c $
# ************************************************************

# ************************************************************
# Pragmas
# ************************************************************

use strict;

use VC12ProjectCreator;

use vars qw(@ISA);
@ISA = qw(VC12ProjectCreator);

## NOTE: We call the constant as a function to support Perl 5.6.
my %info = (Creator::cplusplus() => {'ext'      => '.vcxproj',
                                     'dllexe'   => 'vc14exe',
                                     'libexe'   => 'vc14libexe',
                                     'dll'      => 'vc14dll',
                                     'lib'      => 'vc14lib',
                                     'template' => [ 'vc10', 'vc10filters' ],
                                    },
           );

my %config = ('vcversion' => '14.00',
             );

# ************************************************************
# Subroutine Section
# ************************************************************

sub get_info_hash {
  my($self, $key) = @_;

  ## If we have the setting in our information map, then use it.
  return $info{$key} if (defined $info{$key});

  ## Otherwise, see if our parent type can take care of it.
  return $self->SUPER::get_info_hash($key);
}

sub get_configurable {
  my($self, $name) = @_;

  ## If we have the setting in our config map, then use it.
  return $config{$name} if (defined $config{$name});

  ## Otherwise, see if our parent type can take care of it.
  return $self->SUPER::get_configurable($name);
}

1;
